package Koha::Plugin::Rijks::HoldNoteRequired::Extent;

use Modern::Perl;
use base qw(Koha::Plugins::Base);

our $metadata = {
    name            => 'Rijks_HoldNoteRequired_Extent',
    description     => 'Checks if extent makes hold note required',
    implements      => 'IsHoldNoteRequired', # needed for C4::Reserves
};

sub new {
    my ( $class, $args ) = @_;
    $args->{'metadata'} = $metadata;
    my $self = $class->SUPER::new($args);
    return $self;
}

sub check {
    my ( $self, $args ) = @_;

    # check extent ($a) in MARC21 300 (Physical description)
    my $marcrecord = $args->{record};
    my @fld = $marcrecord->field('300');
    my $re = qr/(\d+)\s*(v\.|vol|dl|delen|band|bd|tle|parts|pts|t\.|tome)/i;
    foreach my $f ( @fld ) {
        next if !$f->subfield('a');
        # Check for something like 3 parts or 22 volumes in 300$a
        return 1 if $f->subfield('a') =~ /$re/ && $1 > 1;
    }
    return;
}

sub install { #nothing to do
    my ( $self, $args ) = @_;
}

sub uninstall { #nothing to do
    my ( $self, $args ) = @_;
}

1;
